{
    "$graph": [
        {
            "class": "Workflow",
            "label": "scatter GATK HaplotypeCaller over intervals",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/contamination_fraction"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/dbsnp_vcf"
                },
                {
                    "type": "string",
                    "id": "#gatk_haplotypecaller_iterator.cwl/emit_reference_confidence"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#gatk_haplotypecaller_iterator.cwl/gvcf_gq_bands"
                },
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "string"
                        }
                    },
                    "id": "#gatk_haplotypecaller_iterator.cwl/intervals"
                },
                {
                    "type": "string",
                    "id": "#gatk_haplotypecaller_iterator.cwl/reference"
                }
            ],
            "steps": [
                {
                    "scatter": [
                        "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/intervals"
                    ],
                    "run": "#gatk_haplotype_caller.cwl",
                    "in": [
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/bam",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/bam"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/contamination_fraction",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/contamination_fraction"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/dbsnp_vcf",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/dbsnp_vcf"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/emit_reference_confidence",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/emit_reference_confidence"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/gvcf_gq_bands",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/gvcf_gq_bands"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/intervals",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/intervals"
                        },
                        {
                            "valueFrom": "${ if (inputs.intervals.length == 1 && inputs.intervals[0].match(/^[0-9A-Za-z]+$/)) { return inputs.intervals[0] + \".g.vcf.gz\"; } else { return \"output.g.vcf.gz\"; } }",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/output_file_name"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/reference",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/reference"
                        }
                    ],
                    "out": [
                        "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/gvcf"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller"
                }
            ],
            "id": "#gatk_haplotypecaller_iterator.cwl",
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/gvcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/gvcf"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "exome alignment and germline variant detection",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/annotate_coding_only"
                },
                {
                    "type": "File",
                    "id": "#main/bam"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/contamination_fraction"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/custom_clinvar_vcf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/custom_gnomad_vcf"
                },
                {
                    "type": "string",
                    "id": "#main/emit_reference_confidence"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "variants",
                    "id": "#main/final_tsv_prefix"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/gvcf_gq_bands"
                },
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "string"
                        }
                    },
                    "id": "#main/intervals"
                },
                {
                    "type": "File",
                    "id": "#main/limit_variant_intervals"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/synonyms_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "default": [
                        "CHROM",
                        "POS",
                        "ID",
                        "REF",
                        "ALT"
                    ],
                    "id": "#main/variants_to_table_fields"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "id": "#main/variants_to_table_genotype_fields"
                },
                {
                    "type": "string",
                    "id": "#main/vep_cache_dir"
                },
                {
                    "type": "string",
                    "doc": "genome assembly to use in vep. Examples: GRCh38 or GRCm38",
                    "id": "#main/vep_ensembl_assembly"
                },
                {
                    "type": "string",
                    "doc": "ensembl species - Must be present in the cache directory. Examples: homo_sapiens or mus_musculus",
                    "id": "#main/vep_ensembl_species"
                },
                {
                    "type": "string",
                    "doc": "ensembl version - Must be present in the cache directory. Example: 95",
                    "id": "#main/vep_ensembl_version"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "default": [
                        "Downstream",
                        "Wildtype"
                    ],
                    "id": "#main/vep_plugins"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "id": "#main/vep_to_table_fields"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/index_coding_vcf/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/coding_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/add_vep_fields_to_table/annotated_variants_tsv",
                    "id": "#main/final_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/index_annotated_vcf/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/final_vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/haplotype_caller/gvcf",
                    "id": "#main/gvcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/limit_variants/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/limited_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/annotate_variants/vep_summary",
                    "id": "#main/vep_summary"
                }
            ],
            "steps": [
                {
                    "run": "#add_vep_fields_to_table.cwl",
                    "in": [
                        {
                            "source": "#main/final_tsv_prefix",
                            "id": "#main/add_vep_fields_to_table/prefix"
                        },
                        {
                            "source": "#main/variants_to_table/variants_tsv",
                            "id": "#main/add_vep_fields_to_table/tsv"
                        },
                        {
                            "source": "#main/limit_variants/filtered_vcf",
                            "id": "#main/add_vep_fields_to_table/vcf"
                        },
                        {
                            "source": "#main/vep_to_table_fields",
                            "id": "#main/add_vep_fields_to_table/vep_fields"
                        }
                    ],
                    "out": [
                        "#main/add_vep_fields_to_table/annotated_variants_tsv"
                    ],
                    "id": "#main/add_vep_fields_to_table"
                },
                {
                    "run": "#vep.cwl",
                    "in": [
                        {
                            "source": "#main/vep_cache_dir",
                            "id": "#main/annotate_variants/cache_dir"
                        },
                        {
                            "source": "#main/annotate_coding_only",
                            "id": "#main/annotate_variants/coding_only"
                        },
                        {
                            "source": "#main/custom_clinvar_vcf",
                            "id": "#main/annotate_variants/custom_clinvar_vcf"
                        },
                        {
                            "source": "#main/custom_gnomad_vcf",
                            "id": "#main/annotate_variants/custom_gnomad_vcf"
                        },
                        {
                            "source": "#main/vep_ensembl_assembly",
                            "id": "#main/annotate_variants/ensembl_assembly"
                        },
                        {
                            "source": "#main/vep_ensembl_species",
                            "id": "#main/annotate_variants/ensembl_species"
                        },
                        {
                            "source": "#main/vep_ensembl_version",
                            "id": "#main/annotate_variants/ensembl_version"
                        },
                        {
                            "source": "#main/vep_plugins",
                            "id": "#main/annotate_variants/plugins"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/annotate_variants/reference"
                        },
                        {
                            "source": "#main/synonyms_file",
                            "id": "#main/annotate_variants/synonyms_file"
                        },
                        {
                            "source": "#main/genotype_gvcfs/genotype_vcf",
                            "id": "#main/annotate_variants/vcf"
                        }
                    ],
                    "out": [
                        "#main/annotate_variants/annotated_vcf",
                        "#main/annotate_variants/vep_summary"
                    ],
                    "id": "#main/annotate_variants"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#main/annotate_variants/annotated_vcf",
                            "id": "#main/bgzip_annotated_vcf/file"
                        }
                    ],
                    "out": [
                        "#main/bgzip_annotated_vcf/bgzipped_file"
                    ],
                    "id": "#main/bgzip_annotated_vcf"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#main/coding_variant_filter/filtered_vcf",
                            "id": "#main/bgzip_coding_vcf/file"
                        }
                    ],
                    "out": [
                        "#main/bgzip_coding_vcf/bgzipped_file"
                    ],
                    "id": "#main/bgzip_coding_vcf"
                },
                {
                    "run": "#filter_vcf_coding_variant.cwl",
                    "in": [
                        {
                            "source": "#main/annotate_variants/annotated_vcf",
                            "id": "#main/coding_variant_filter/vcf"
                        }
                    ],
                    "out": [
                        "#main/coding_variant_filter/filtered_vcf"
                    ],
                    "id": "#main/coding_variant_filter"
                },
                {
                    "run": "#gatk_genotypegvcfs.cwl",
                    "in": [
                        {
                            "source": "#main/haplotype_caller/gvcf",
                            "id": "#main/genotype_gvcfs/gvcfs"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/genotype_gvcfs/reference"
                        }
                    ],
                    "out": [
                        "#main/genotype_gvcfs/genotype_vcf"
                    ],
                    "id": "#main/genotype_gvcfs"
                },
                {
                    "run": "#gatk_haplotypecaller_iterator.cwl",
                    "in": [
                        {
                            "source": "#main/bam",
                            "id": "#main/haplotype_caller/bam"
                        },
                        {
                            "source": "#main/contamination_fraction",
                            "id": "#main/haplotype_caller/contamination_fraction"
                        },
                        {
                            "source": "#main/emit_reference_confidence",
                            "id": "#main/haplotype_caller/emit_reference_confidence"
                        },
                        {
                            "source": "#main/gvcf_gq_bands",
                            "id": "#main/haplotype_caller/gvcf_gq_bands"
                        },
                        {
                            "source": "#main/intervals",
                            "id": "#main/haplotype_caller/intervals"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/haplotype_caller/reference"
                        }
                    ],
                    "out": [
                        "#main/haplotype_caller/gvcf"
                    ],
                    "id": "#main/haplotype_caller"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#main/bgzip_annotated_vcf/bgzipped_file",
                            "id": "#main/index_annotated_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#main/index_annotated_vcf/indexed_vcf"
                    ],
                    "id": "#main/index_annotated_vcf"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#main/bgzip_coding_vcf/bgzipped_file",
                            "id": "#main/index_coding_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#main/index_coding_vcf/indexed_vcf"
                    ],
                    "id": "#main/index_coding_vcf"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#main/limit_variants/exclude_filtered"
                        },
                        {
                            "source": "#main/limit_variant_intervals",
                            "id": "#main/limit_variants/interval_list"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/limit_variants/reference"
                        },
                        {
                            "source": "#main/index_coding_vcf/indexed_vcf",
                            "id": "#main/limit_variants/vcf"
                        }
                    ],
                    "out": [
                        "#main/limit_variants/filtered_vcf"
                    ],
                    "id": "#main/limit_variants"
                },
                {
                    "run": "#variants_to_table.cwl",
                    "in": [
                        {
                            "source": "#main/variants_to_table_fields",
                            "id": "#main/variants_to_table/fields"
                        },
                        {
                            "source": "#main/variants_to_table_genotype_fields",
                            "id": "#main/variants_to_table/genotype_fields"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/variants_to_table/reference"
                        },
                        {
                            "source": "#main/limit_variants/filtered_vcf",
                            "id": "#main/variants_to_table/vcf"
                        }
                    ],
                    "out": [
                        "#main/variants_to_table/variants_tsv"
                    ],
                    "id": "#main/variants_to_table"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "label": "add VEP annotation to report",
            "baseCommand": [
                "vep-annotation-reporter"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "griffithlab/vatools:3.1.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.prefix).annotated.tsv"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "variants",
                    "id": "#add_vep_fields_to_table.cwl/prefix"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "id": "#add_vep_fields_to_table.cwl/tsv"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#add_vep_fields_to_table.cwl/vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "Consequence",
                        "SYMBOL",
                        "Feature",
                        "HGVSc",
                        "HGVSp"
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#add_vep_fields_to_table.cwl/vep_fields"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.prefix).annotated.tsv"
                    },
                    "id": "#add_vep_fields_to_table.cwl/annotated_variants_tsv"
                }
            ],
            "id": "#add_vep_fields_to_table.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "bgzip VCF",
            "baseCommand": [
                "/opt/htslib/bin/bgzip"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "$(inputs.file.basename).gz",
            "arguments": [
                "-c"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bgzip.cwl/file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bgzip.cwl/bgzipped_file",
                    "outputBinding": {
                        "glob": "$(inputs.file.basename).gz"
                    }
                }
            ],
            "id": "#bgzip.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Coding Variant filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/vcf_check.pl"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/vep_helper-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.vcf.path)"
                },
                {
                    "valueFrom": "$(runtime.outdir)/annotated.coding_variant_filtered.vcf"
                },
                "/usr/bin/perl",
                "/opt/vep/src/ensembl-vep/filter_vep",
                "--format",
                "vcf",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.coding_variant_filtered.vcf"
                },
                "--ontology",
                "--filter",
                "Consequence is coding_sequence_variant"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#filter_vcf_coding_variant.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.coding_variant_filtered.vcf"
                    },
                    "id": "#filter_vcf_coding_variant.cwl/filtered_vcf"
                }
            ],
            "id": "#filter_vcf_coding_variant.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "GATK HaplotypeCaller",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "GenotypeGVCFs"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 9000
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.5.0"
                }
            ],
            "arguments": [
                "-o",
                "genotype.vcf.gz"
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "--variant"
                        }
                    },
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#gatk_genotypegvcfs.cwl/gvcfs"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#gatk_genotypegvcfs.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "genotype.vcf.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_genotypegvcfs.cwl/genotype_vcf"
                }
            ],
            "id": "#gatk_genotypegvcfs.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "GATK HaplotypeCaller",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "HaplotypeCaller"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 10000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.5.0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#gatk_haplotype_caller.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-contamination",
                        "position": 7
                    },
                    "id": "#gatk_haplotype_caller.cwl/contamination_fraction"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--dbsnp",
                        "position": 6
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotype_caller.cwl/dbsnp_vcf"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-ERC",
                        "position": 3
                    },
                    "id": "#gatk_haplotype_caller.cwl/emit_reference_confidence"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-GQB"
                        }
                    },
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#gatk_haplotype_caller.cwl/gvcf_gq_bands"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-L"
                        }
                    },
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#gatk_haplotype_caller.cwl/intervals"
                },
                {
                    "type": "string",
                    "default": "output.g.vcf.gz",
                    "inputBinding": {
                        "prefix": "-o",
                        "position": 8
                    },
                    "id": "#gatk_haplotype_caller.cwl/output_file_name"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#gatk_haplotype_caller.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_file_name)"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotype_caller.cwl/gvcf"
                }
            ],
            "id": "#gatk_haplotype_caller.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf index",
            "arguments": [
                "cp",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)/$(inputs.vcf.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/bin/tabix",
                "-p",
                "vcf"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 1
                    },
                    "id": "#index_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "id": "#index_vcf.cwl/indexed_vcf"
                }
            ],
            "id": "#index_vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "SelectVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--excludeFiltered",
                        "position": 4
                    },
                    "id": "#select_variants.cwl/exclude_filtered"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 3
                    },
                    "id": "#select_variants.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "select_variants",
                    "id": "#select_variants.cwl/output_vcf_basename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#select_variants.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--sample_name",
                        "position": 5
                    },
                    "doc": "include genotypes from this sample",
                    "id": "#select_variants.cwl/samples_to_include"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#select_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf.gz"
                    },
                    "id": "#select_variants.cwl/filtered_vcf"
                }
            ],
            "id": "#select_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "VariantsToTable"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "--allowMissingData",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/variants.tsv"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-F"
                        }
                    },
                    "default": [
                        "CHROM",
                        "POS",
                        "ID",
                        "REF",
                        "ALT",
                        "set"
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#variants_to_table.cwl/fields"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-GF"
                        }
                    },
                    "default": [
                        "GT",
                        "AD",
                        "DP",
                        "AF"
                    ],
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#variants_to_table.cwl/genotype_fields"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#variants_to_table.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#variants_to_table.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "variants.tsv"
                    },
                    "id": "#variants_to_table.cwl/variants_tsv"
                }
            ],
            "id": "#variants_to_table.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Ensembl Variant Effect Predictor",
            "baseCommand": [
                "/usr/bin/perl",
                "-I",
                "/opt/lib/perl/VEP/Plugins",
                "/usr/bin/variant_effect_predictor.pl"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 4,
                    "ramMin": 64000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/vep_helper-cwl:1.1.0"
                }
            ],
            "arguments": [
                "--format",
                "vcf",
                "--vcf",
                "--fork",
                "4",
                "--term",
                "SO",
                "--transcript_version",
                "--offline",
                "--cache",
                "--symbol",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--dir",
                        "position": 4
                    },
                    "id": "#vep.cwl/cache_dir"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "--coding_only",
                        "position": 3
                    },
                    "default": false,
                    "id": "#vep.cwl/coding_only"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "inputBinding": {
                        "valueFrom": "${\n    if (inputs.custom_clinvar_vcf) {\n        return [\"--custom\", inputs.custom_clinvar_vcf.path + \",clinvar,vcf,exact,0,CLINSIGN,PHENOTYPE,SCORE,RCVACC,TESTEDINGTR,PHENOTYPELIST,NUMSUBMIT,GUIDELINES\"]\n\n    }\n    else {\n        return []\n    }\n}\n",
                        "position": 7
                    },
                    "id": "#vep.cwl/custom_clinvar_vcf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "inputBinding": {
                        "valueFrom": "${\n    if (inputs.custom_gnomad_vcf) {\n        return ['--check_existing', '--custom', inputs.custom_gnomad_vcf.path + ',gnomADe,vcf,exact,0,AF,AF_AFR,AF_AMR,AF_ASJ,AF_EAS,AF_FIN,AF_NFE,AF_OTH,AF_SAS']\n    }\n    else {\n        return []\n    }\n}\n",
                        "position": 6
                    },
                    "id": "#vep.cwl/custom_gnomad_vcf"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--assembly",
                        "position": 11
                    },
                    "doc": "genome assembly to use in vep. Examples: 'GRCh38' or 'GRCm38'",
                    "id": "#vep.cwl/ensembl_assembly"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--species",
                        "position": 13
                    },
                    "doc": "ensembl species - Must be present in the cache directory. Examples: 'homo_sapiens' or 'mus_musculus'",
                    "id": "#vep.cwl/ensembl_species"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--cache_version",
                        "position": 12
                    },
                    "doc": "ensembl version - Must be present in the cache directory. Example: '95'",
                    "id": "#vep.cwl/ensembl_version"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--everything",
                        "position": 10
                    },
                    "id": "#vep.cwl/everything"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#vep.cwl/pick/pick",
                                "#vep.cwl/pick/flag_pick",
                                "#vep.cwl/pick/pick_allele",
                                "#vep.cwl/pick/per_gene",
                                "#vep.cwl/pick/pick_allele_gene",
                                "#vep.cwl/pick/flag_pick_allele",
                                "#vep.cwl/pick/flag_pick_allele_gene"
                            ]
                        }
                    ],
                    "default": "flag_pick",
                    "inputBinding": {
                        "prefix": "--",
                        "separate": false,
                        "position": 7
                    },
                    "id": "#vep.cwl/pick"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "--plugin"
                        }
                    },
                    "inputBinding": {
                        "position": 9
                    },
                    "id": "#vep.cwl/plugins"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--fasta",
                        "position": 8
                    },
                    "id": "#vep.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--synonyms",
                        "position": 2
                    },
                    "id": "#vep.cwl/synonyms_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#vep.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.vcf"
                    },
                    "id": "#vep.cwl/annotated_vcf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.vcf_summary.html"
                    },
                    "id": "#vep.cwl/vep_summary"
                }
            ],
            "id": "#vep.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
